#!/bin/bash
#
# odoodevs_set.sh
# Modified: 2024/12/09 10:27:00
# Derechos de Autor (C) [2024] [Mauro Rosero P. <mauro@roser.one>]
#
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

DEVSPATH=devs
BIN_HOME=$HOME/$DEVSPATH
BIN_MESG=bin/msg
BIN_LIBS=bin/lib

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# LOAD BASE BASH LIBRARY
source $BIN_HOME/$BIN_LIBS/base.lib
#baselib_test

# LOAD CONSOLE BASH LIBRARY
source $BIN_HOME/$BIN_LIBS/console.lib
#consolelib_test

# LOAD GPG BASH LIBRARY
source $BIN_HOME/$BIN_LIBS/odoo.lib
#gpglib_test

# Load head messages
load_messages $BIN_HOME $BIN_MESG $BIN_LANG "head"

# Load odoo messages
load_messages $BIN_HOME $BIN_MESG $BIN_LANG "odoo"


########### MAIN PROGRAM ###########

# Set program title
title="$head_000 $odmsg_000"
apps_title="${odmsg_100} ${odmsg_001}"

# Check if dialog is not installed, exited!
command_installed "dialog"
if [ $? -ne 0 ]
then
  display_devstools_header "${odmsg_000}"
  echo "${head_001}"
  exit 200
fi

# Check if os is valid!
get_osname
if [ "${os_name}" == "${head_unknow}" ]
then
  dialog_error_box "${head_error}" "${head_os_error}"
  exit 3
fi

# Set odoo developers structure commands & paths
dialog_yesno "${odmsg_101}"
case ${result} in
  0)
    odoo_developers
    rc=$?
    case $rc in
      0)
        exit 0
        ;;
      1)
        dialog_error_box "${head_error}" "${odmsg_002}"
        clear
        exit 1
        ;;
      2)
        dialog_error_box "${head_error}" "${odmsg_103}"
        clear
        exit 2
        ;;
      3)
        dialog_error_box "${head_error}" "${odmsg_odmsg_104}"
        clear
        exit 3
        ;;
      *)
        dialog_error_box "${head_error}" "${head_op_error} (${rc})"
        ;;
    esac
    ;;
  *)
    dialog_error_box "${head_error}" "${head_op_error}"
    ;;
esac

# End Main Program
clear
